const CounterpartyOptions = [
    {
        name: 'Genesis Global',
        value: 'GENESIS',
    },
    {
        name: 'Acme Global',
        value: 'ACME',
    },
];
const InstrumentOptions = [
    {
        name: 'Bond',
        value: 'BOND',
    },
    {
        name: 'Equity',
        value: 'EQUITY',
    },
];
export const uiSchema = {
    type: 'VerticalLayout',
    dsPrefix: 'zero',
    elements: [
        {
            type: 'Group',
            label: 'Group 1',
            scope: '#/properties/group1',
            options: {
                childElements: [
                    {
                        type: 'VerticalLayout',
                        elements: [
                            {
                                type: 'Control',
                                scope: '#/properties/group1/properties/NAME',
                                label: 'Name',
                            },
                        ],
                    },
                ],
            },
        },
        {
            type: 'Group',
            label: 'Group 2',
            scope: '#/properties/group2',
            options: {
                childElements: [
                    {
                        type: 'LayoutVertical2Columns',
                        elements: [
                            {
                                type: 'Control',
                                scope: '#/properties/group2/properties/QUANTITY',
                                label: 'Quantity',
                            },
                            {
                                type: 'Control',
                                scope: '#/properties/group2/properties/PRICE',
                                label: 'Price',
                            },
                            {
                                type: 'Control',
                                scope: '#/properties/group2/properties/COUNTERPARTY_ID',
                                options: {
                                    data: CounterpartyOptions,
                                    valueField: 'value',
                                    labelField: 'name',
                                },
                                label: 'Counterparty',
                            },
                            {
                                type: 'Control',
                                scope: '#/properties/group2/properties/INSTRUMENT_ID',
                                options: {
                                    data: InstrumentOptions,
                                    valueField: 'value',
                                    labelField: 'name',
                                },
                                label: 'Instrument',
                            },
                            {
                                type: 'Control',
                                scope: '#/properties/group2/properties/SIDE',
                                label: 'Side',
                            },
                            {
                                type: 'Control',
                                scope: '#/properties/group2/properties/TRADE_DATE',
                                label: 'Trade Date',
                            },
                            {
                                type: 'Control',
                                scope: '#/properties/group2/properties/ACTIVE',
                                label: 'Active',
                            },
                        ],
                    },
                ],
            },
        },
    ],
};
export const JSON_SCHEMA = {
    type: 'object',
    properties: {
        group1: {
            type: 'object',
            properties: {
                NAME: {
                    type: 'string',
                },
            },
        },
        group2: {
            type: 'object',
            properties: {
                QUANTITY: {
                    type: 'number',
                },
                PRICE: {
                    type: 'number',
                },
                COUNTERPARTY_ID: {
                    type: 'string',
                },
                INSTRUMENT_ID: {
                    type: 'string',
                },
                SIDE: {
                    type: 'string',
                    enum: ['BUY', 'SELL'],
                },
                TRADE_DATE: {
                    type: 'number',
                    format: 'date',
                    description: 'org.joda.time.DateTime',
                },
                ACTIVE: {
                    type: 'boolean',
                },
            },
            required: ['QUANTITY', 'PRICE'],
        },
    },
};
export const uiSchemaArray = {
    type: 'VerticalLayout',
    dsPrefix: 'zero',
    elements: [
        {
            type: 'Control',
            scope: '#/properties/users',
            options: {
                childUiSchema: {
                    type: 'HorizontalLayout',
                    elements: [
                        {
                            type: 'Control',
                            scope: '#/properties/firstname',
                            label: 'First Name',
                        },
                        {
                            type: 'Control',
                            scope: '#/properties/lastname',
                            label: 'Last Name',
                        },
                        {
                            type: 'Control',
                            scope: '#/properties/email',
                            label: 'Email',
                        },
                    ],
                },
            },
        },
    ],
};
export const JSON_SCHEMA_ARRAY = {
    type: 'object',
    properties: {
        users: {
            type: 'array',
            items: {
                type: 'object',
                title: 'Users',
                properties: {
                    firstname: {
                        type: 'string',
                    },
                    lastname: {
                        type: 'string',
                    },
                    email: {
                        type: 'string',
                        format: 'email',
                    },
                },
                required: ['firstname'],
            },
        },
    },
};
